Module data

Module data 

The data module defines data structures and constants used in minidump parsing.

Structs

CONTEXT_X64
CONTEXT structure representing 64 bits
CONTEXT_X86
CONTEXT structure representing 32 bits
HandleArgs
HandleArgsBuilder
A builder for HandleArgs objects. Compatible with binrw::args!.
MINIDUMP_DIRECTORY
Contains the information needed to access a specific data stream in a minidump file.
MINIDUMP_EXCEPTION
Represents an exception information stream.
MINIDUMP_EXCEPTION_STREAM
Represents an exception information stream.
MINIDUMP_HANDLE_DATA_STREAM
Represents the header for a handle data stream.
MINIDUMP_HANDLE_DESCRIPTOR
Contains the state of an individual system handle at the time the minidump was written.
MINIDUMP_HEADER
Contains header information for the minidump file.
MINIDUMP_LOCATION_DESCRIPTOR
Contains information describing the location of a data stream within a minidump file.
MINIDUMP_MEMORY64_LIST
Contains a list of memory ranges.
MINIDUMP_MEMORY_DESCRIPTOR
Describes a range of memory.
MINIDUMP_MEMORY_DESCRIPTOR64
Describes a range of memory.
MINIDUMP_MEMORY_INFO
Describes a region of memory.
MINIDUMP_MEMORY_INFO_LIST
Contains a list of memory ranges.
MINIDUMP_MODULE
Contains information for a specific module.
MINIDUMP_MODULE_LIST
Contains a list of modules.
MINIDUMP_STRING
Describes a string.
MINIDUMP_SYSTEM_INFO
Contains processor and operating system information.
MINIDUMP_THREAD
Contains information for a specific thread.
MINIDUMP_THREAD_LIST
Contains a list of threads.
VS_FIXEDFILEINFO
Contains version information for a file.
VS_FIXEDFILEINFO_FILE_FLAGS
Contains a bitmask that specifies the Boolean attributes of the file.
VS_FIXEDFILEINFO_FILE_OS
The operating system for which this file was designed.

Enums

MINIDUMP_STREAM_TYPE
Represents the type of a minidump data stream.

Constants

ARCH_X64
Architecture code for 64-bit systems (x86_64).
ARCH_X86
Architecture code for 32-bit systems (x86).
DUMP_FLAGS
Default flags for configuring dumps.
EXCEPTION_MAXIMUM_PARAMETERS
Maximum number of parameters associated with an exception.
MINIDUMP_SIGNATURE
Signature to identify Minidump files (“MDMP” in ASCII).