pub struct VS_FIXEDFILEINFO {Show 13 fields
pub dwSignature: u32,
pub dwStrucVersion: u32,
pub dwFileVersionMS: u32,
pub dwFileVersionLS: u32,
pub dwProductVersionMS: u32,
pub dwProductVersionLS: u32,
pub dwFileFlagsMask: u32,
pub dwFileFlags: VS_FIXEDFILEINFO_FILE_FLAGS,
pub dwFileOS: VS_FIXEDFILEINFO_FILE_OS,
pub dwFileType: u32,
pub dwFileSubtype: u32,
pub dwFileDateMS: u32,
pub dwFileDateLS: u32,
}Expand description
Contains version information for a file.
For more details, see the official Microsoft documentation
Fields
dwSignature: u32Contains the value 0xFEEF04BD.
dwStrucVersion: u32The binary version number of this structure.
dwFileVersionMS: u32The most significant 32 bits of the file’s binary version number.
dwFileVersionLS: u32The least significant 32 bits of the file’s binary version number.
dwProductVersionMS: u32The most significant 32 bits of the binary version number of the product with which this file was distributed.
dwProductVersionLS: u32The least significant 32 bits of the binary version number of the product with which this file was distributed.
dwFileFlagsMask: u32Contains a bitmask that specifies the valid bits in dwFileFlags.
dwFileFlags: VS_FIXEDFILEINFO_FILE_FLAGSContains a bitmask that specifies the Boolean attributes of the file.
dwFileOS: VS_FIXEDFILEINFO_FILE_OSThe operating system for which this file was designed.
dwFileType: u32The general type of file.
dwFileSubtype: u32The function of the file.
dwFileDateMS: u32The most significant 32 bits of the file’s 64-bit binary creation date and time stamp.
dwFileDateLS: u32The least significant 32 bits of the file’s 64-bit binary creation date and time stamp.