The error module defines error types used throughout the library.
Enums
- User
DmpError - Represents errors that may occur during the processing of a minidump file.
The error module defines error types used throughout the library.