The data module defines data structures and constants used in minidump parsing.
Structs
- CONTEXT_
X64 - CONTEXT structure representing 64 bits
- CONTEXT_
X86 - CONTEXT structure representing 32 bits
- Handle
Args - Handle
Args Builder - A builder for
HandleArgsobjects. Compatible withbinrw::args!. - MINIDUMP_
DIRECTORY - Contains the information needed to access a specific data stream in a minidump file.
- MINIDUMP_
EXCEPTION - Represents an exception information stream.
- MINIDUMP_
EXCEPTION_ STREAM - Represents an exception information stream.
- MINIDUMP_
HANDLE_ DATA_ STREAM - Represents the header for a handle data stream.
- MINIDUMP_
HANDLE_ DESCRIPTOR - Contains the state of an individual system handle at the time the minidump was written.
- MINIDUMP_
HEADER - Contains header information for the minidump file.
- MINIDUMP_
LOCATION_ DESCRIPTOR - Contains information describing the location of a data stream within a minidump file.
- MINIDUMP_
MEMOR Y64_ LIST - Contains a list of memory ranges.
- MINIDUMP_
MEMORY_ DESCRIPTOR - Describes a range of memory.
- MINIDUMP_
MEMORY_ DESCRIPTO R64 - Describes a range of memory.
- MINIDUMP_
MEMORY_ INFO - Describes a region of memory.
- MINIDUMP_
MEMORY_ INFO_ LIST - Contains a list of memory ranges.
- MINIDUMP_
MODULE - Contains information for a specific module.
- MINIDUMP_
MODULE_ LIST - Contains a list of modules.
- MINIDUMP_
STRING - Describes a string.
- MINIDUMP_
SYSTEM_ INFO - Contains processor and operating system information.
- MINIDUMP_
THREAD - Contains information for a specific thread.
- MINIDUMP_
THREAD_ LIST - Contains a list of threads.
- VS_
FIXEDFILEINFO - Contains version information for a file.
- VS_
FIXEDFILEINFO_ FILE_ FLAGS - Contains a bitmask that specifies the Boolean attributes of the file.
- VS_
FIXEDFILEINFO_ FILE_ OS - The operating system for which this file was designed.
Enums
- MINIDUMP_
STREAM_ TYPE - Represents the type of a minidump data stream.
Constants
- ARCH_
X64 - Architecture code for 64-bit systems (x86_64).
- ARCH_
X86 - Architecture code for 32-bit systems (x86).
- DUMP_
FLAGS - Default flags for configuring dumps.
- EXCEPTION_
MAXIMUM_ PARAMETERS - Maximum number of parameters associated with an exception.
- MINIDUMP_
SIGNATURE - Signature to identify Minidump files (“MDMP” in ASCII).